'''*****************************************************************************
***  This file is part of Similis.                                           ***
***                                                                          ***
***  Copyright (C) 2020                                                      ***
***  John Schneiderman <Licensing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU General Public License as published          ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU General Public License for more details.                    ***
***                                                                          ***
***  You should have received a copy of the GNU General Public License       ***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*****************************************************************************'''
import unittest

import AddSimilisPath
from Scoring import ExaminedFile, Percentage
from NameScoring import FileNameScorer


class FileNameScorerTests(unittest.TestCase):
    def setUp(self):
        self.__scorer = FileNameScorer()

    def test_no_words_in_common_should_be_0_percent(self):
        source = ExaminedFile('/', '/dir', 'Some-Big-Text-With-Lorem-Ipsum-In-It.txt')
        compare = ExaminedFile('/', '/dir', 'Cool-file-bro.lst')
        score = self.__scorer.score(source, compare)
        self.assertEqual(score, Percentage(0))

    def test_halfNames_should_be_50_percent(self):
        source = ExaminedFile('/', '/dir', 'Big-Text-With-Lorem-Ipsum-In-It.txt')
        compare = ExaminedFile('/', '/dir', 'Cool-Text-Not-Lorem-Ipsum-Dog-Cat.txt')
        score = self.__scorer.score(source, compare)
        self.assertEqual(score, Percentage(50))

    def test_sameNames_should_be_100_percent(self):
        source = ExaminedFile('/', '/dir', 'Some-Big-Text-With-Lorem-Ipsum-In-It.txt')
        compare = ExaminedFile('/', '/dir', 'Some-Big-Text-With-Lorem-Ipsum-In-It.txt')
        score = self.__scorer.score(source, compare)
        self.assertEqual(score, Percentage(100))


if __name__ == "__main__":
    unittest.main()
